@@ -54,11 +54,11 @@ pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
 // this application to the Update server.
 pref("app.id", "{ec8030f7-c20a-464f-9b0e-13a3a9e97384}");
 pref("app.version", 
-"1.0.1"
+"1.0.4"
 );
 pref("app.extensions.version", "1.0");
 pref("app.build_id", 
-"0000000000"
+"2005061001"
 );
 
 // App-specific update preferences
@@ -116,7 +116,8 @@ pref("update.showSlidingNotification", true);   // Windows-only slide-up taskbar
 // 2 = high   (new version of Firefox/Security patch)
 pref("update.severity", 0); 
 
-pref("xpinstall.whitelist.add", "update.mozilla.org,addons.mozilla.org");
+pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 pref("keyword.enabled", true);
 pref("keyword.URL", "http://www.google.com/search?btnI=I%27m+Feeling+Lucky&ie=UTF-8&oe=UTF-8&q=");
@@ -124,7 +125,7 @@ pref("keyword.URL", "http://www.google.com/search?btnI=I%27m+Feeling+Lucky&ie=UT
 pref("general.skins.selectedSkin", "classic/1.0");
 pref("general.useragent.vendor", "Firefox");
 pref("general.useragent.vendorSub", 
-"1.0.1"
+"1.0.4"
 );
 
 pref("general.smoothScroll", false);
